# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/perpetuals/query.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\"#\n\x15QueryPerpetualRequest\x12\n\n\x02id\x18\x01 \x01(\r\"U\n\x16QueryPerpetualResponse\x12;\n\tperpetual\x18\x01 \x01(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\"W\n\x19QueryAllPerpetualsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1aQueryAllPerpetualsResponse\x12;\n\tperpetual\x18\x01 \x03(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xce\x02\n\x05Query\x12\x9d\x01\n\tPerpetual\x12..dydxprotocol.perpetuals.QueryPerpetualRequest\x1a/.dydxprotocol.perpetuals.QueryPerpetualResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/perpetuals/perpetual/{id}\x12\xa4\x01\n\rAllPerpetuals\x12\x32.dydxprotocol.perpetuals.QueryAllPerpetualsRequest\x1a\x33.dydxprotocol.perpetuals.QueryAllPerpetualsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/perpetuals/perpetualB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _QUERYPERPETUALRESPONSE.fields_by_name['perpetual']._options = None
  _QUERYPERPETUALRESPONSE.fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _QUERYALLPERPETUALSRESPONSE.fields_by_name['perpetual']._options = None
  _QUERYALLPERPETUALSRESPONSE.fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Perpetual']._options = None
  _QUERY.methods_by_name['Perpetual']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/perpetuals/perpetual/{id}'
  _QUERY.methods_by_name['AllPerpetuals']._options = None
  _QUERY.methods_by_name['AllPerpetuals']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/perpetuals/perpetual'
  _globals['_QUERYPERPETUALREQUEST']._serialized_start=201
  _globals['_QUERYPERPETUALREQUEST']._serialized_end=236
  _globals['_QUERYPERPETUALRESPONSE']._serialized_start=238
  _globals['_QUERYPERPETUALRESPONSE']._serialized_end=323
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_start=325
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_end=412
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_start=415
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_end=565
  _globals['_QUERY']._serialized_start=568
  _globals['_QUERY']._serialized_end=902
# @@protoc_insertion_point(module_scope)
