# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/daemons/liquidation/liquidation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dydxprotocol/daemons/liquidation/liquidation.proto\x12 dydxprotocol.daemons.liquidation\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"c\n\x1bLiquidateSubaccountsRequest\x12\x44\n\x0esubaccount_ids\x18\x01 \x03(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\"\x1e\n\x1cLiquidateSubaccountsResponse2\xac\x01\n\x12LiquidationService\x12\x95\x01\n\x14LiquidateSubaccounts\x12=.dydxprotocol.daemons.liquidation.LiquidateSubaccountsRequest\x1a>.dydxprotocol.daemons.liquidation.LiquidateSubaccountsResponseBCZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.liquidation.liquidation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/api'
  _LIQUIDATESUBACCOUNTSREQUEST.fields_by_name['subaccount_ids']._options = None
  _LIQUIDATESUBACCOUNTSREQUEST.fields_by_name['subaccount_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_start=153
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_end=252
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_start=254
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_end=284
  _globals['_LIQUIDATIONSERVICE']._serialized_start=287
  _globals['_LIQUIDATIONSERVICE']._serialized_end=459
# @@protoc_insertion_point(module_scope)
